/**
 */
package de.mdelab.mlstorypatterns;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Link Order Constraint</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * LinkOrderConstraints specify a relative ordering between two objects in an ordered link. Depending on the value of constraintType, the target object of successorLink must be a direct successor or any successor of the target of predecessorLink.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getConstraintType <em>Constraint Type</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink <em>Predecessor Link</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern <em>Story Pattern</em>}</li>
 * </ul>
 * </p>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint()
 * @model
 * @generated
 */
public interface LinkOrderConstraint extends MLElementWithUUID,
		MLAnnotatedElement {
	/**
	 * Returns the value of the '<em><b>Constraint Type</b></em>' attribute.
	 * The default value is <code>"ANY_SUCCESSOR"</code>.
	 * The literals are from the enumeration {@link de.mdelab.mlstorypatterns.LinkOrderConstraintEnum}.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Constraint Type</em>' attribute isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Constraint Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraintEnum
	 * @see #setConstraintType(LinkOrderConstraintEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_ConstraintType()
	 * @model default="ANY_SUCCESSOR" required="true"
	 * @generated
	 */
	LinkOrderConstraintEnum getConstraintType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getConstraintType <em>Constraint Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Constraint Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraintEnum
	 * @see #getConstraintType()
	 * @generated
	 */
	void setConstraintType(LinkOrderConstraintEnum value);

	/**
	 * Returns the value of the '<em><b>Predecessor Link</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints <em>Outgoing Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Predecessor Link</em>' reference isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Predecessor Link</em>' reference.
	 * @see #setPredecessorLink(StoryPatternLink)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_PredecessorLink()
	 * @see de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints
	 * @model opposite="outgoingLinkOrderConstraints" resolveProxies="false" required="true"
	 * @generated
	 */
	StoryPatternLink getPredecessorLink();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink <em>Predecessor Link</em>}' reference.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Predecessor Link</em>' reference.
	 * @see #getPredecessorLink()
	 * @generated
	 */
	void setPredecessorLink(StoryPatternLink value);

	/**
	 * Returns the value of the '<em><b>Successor Link</b></em>' reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints <em>Incoming Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Successor Link</em>' reference isn't clear,
	 * there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Successor Link</em>' reference.
	 * @see #setSuccessorLink(StoryPatternLink)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_SuccessorLink()
	 * @see de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints
	 * @model opposite="incomingLinkOrderConstraints" resolveProxies="false" required="true"
	 * @generated
	 */
	StoryPatternLink getSuccessorLink();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}' reference.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Successor Link</em>' reference.
	 * @see #getSuccessorLink()
	 * @generated
	 */
	void setSuccessorLink(StoryPatternLink value);

	/**
	 * Returns the value of the '<em><b>Story Pattern</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPattern#getLinkOrderConstraints <em>Link Order Constraints</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Story Pattern</em>' container reference isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Story Pattern</em>' container reference.
	 * @see #setStoryPattern(StoryPattern)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getLinkOrderConstraint_StoryPattern()
	 * @see de.mdelab.mlstorypatterns.StoryPattern#getLinkOrderConstraints
	 * @model opposite="linkOrderConstraints" resolveProxies="false" required="true" transient="false"
	 * @generated
	 */
	StoryPattern getStoryPattern();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern <em>Story Pattern</em>}' container reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Story Pattern</em>' container reference.
	 * @see #getStoryPattern()
	 * @generated
	 */
	void setStoryPattern(StoryPattern value);

} // LinkOrderConstraint
