/**
 */
package de.mdelab.mlstorypatterns;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import de.mdelab.mlcore.MLNamedElement;
import de.mdelab.mlexpressions.MLExpression;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A StoryPattern contains a graph transformation rule.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getStoryPatternLinks <em>Story Pattern Links</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getStoryPatternObjects <em>Story Pattern Objects</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getLinkOrderConstraints <em>Link Order Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getConstraints <em>Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getNegativeApplicationConditions <em>Negative Application Conditions</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPattern#getContainingPattern <em>Containing Pattern</em>}</li>
 * </ul>
 * </p>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern()
 * @model
 * @generated
 */
public interface StoryPattern extends MLElementWithUUID, MLAnnotatedElement,
		MLNamedElement {
	/**
	 * Returns the value of the '<em><b>Story Pattern Links</b></em>' containment reference list.
	 * The list contents are of type {@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getStoryPattern <em>Story Pattern</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Story Pattern Links</em>' containment
	 * reference list isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Story Pattern Links</em>' containment reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_StoryPatternLinks()
	 * @see de.mdelab.mlstorypatterns.AbstractStoryPatternLink#getStoryPattern
	 * @model opposite="storyPattern" containment="true" ordered="false"
	 * @generated
	 */
	EList<AbstractStoryPatternLink> getStoryPatternLinks();

	/**
	 * Returns the value of the '<em><b>Story Pattern Objects</b></em>' containment reference list.
	 * The list contents are of type {@link de.mdelab.mlstorypatterns.AbstractStoryPatternObject}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getStoryPattern <em>Story Pattern</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Story Pattern Objects</em>' containment
	 * reference list isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Story Pattern Objects</em>' containment reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_StoryPatternObjects()
	 * @see de.mdelab.mlstorypatterns.AbstractStoryPatternObject#getStoryPattern
	 * @model opposite="storyPattern" containment="true" required="true" ordered="false"
	 * @generated
	 */
	EList<AbstractStoryPatternObject> getStoryPatternObjects();

	/**
	 * Returns the value of the '<em><b>Link Order Constraints</b></em>' containment reference list.
	 * The list contents are of type {@link de.mdelab.mlstorypatterns.LinkOrderConstraint}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern <em>Story Pattern</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Link Order Constraints</em>' containment
	 * reference list isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Link Order Constraints</em>' containment reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_LinkOrderConstraints()
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraint#getStoryPattern
	 * @model opposite="storyPattern" containment="true" ordered="false"
	 * @generated
	 */
	EList<LinkOrderConstraint> getLinkOrderConstraints();

	/**
	 * Returns the value of the '<em><b>Constraints</b></em>' containment
	 * reference list. The list contents are of type
	 * {@link de.mdelab.mlexpressions.MLExpression}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> Additional constraints
	 * that have to be satsified by a valid match. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Constraints</em>' containment reference
	 *         list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_Constraints()
	 * @model containment="true" ordered="false"
	 * @generated
	 */
	EList<MLExpression> getConstraints();

	/**
	 * Returns the value of the '<em><b>Negative Application Conditions</b></em>
	 * ' containment reference list. The list contents are of type
	 * {@link de.mdelab.mlstorypatterns.StoryPattern}. It is bidirectional and
	 * its opposite is '
	 * {@link de.mdelab.mlstorypatterns.StoryPattern#getContainingPattern
	 * <em>Containing Pattern</em>}'. <!-- begin-user-doc --> <!-- end-user-doc
	 * --> <!-- begin-model-doc --> Negative application conditions are story
	 * patterns for which no match may be found, so that the whole story pattern
	 * can be matched. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Negative Application Conditions</em>'
	 *         containment reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_NegativeApplicationConditions()
	 * @see de.mdelab.mlstorypatterns.StoryPattern#getContainingPattern
	 * @model opposite="containingPattern" containment="true" ordered="false"
	 * @generated
	 */
	EList<StoryPattern> getNegativeApplicationConditions();

	/**
	 * Returns the value of the '<em><b>Containing Pattern</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.StoryPattern#getNegativeApplicationConditions <em>Negative Application Conditions</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Containing Pattern</em>' container reference
	 * isn't clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Containing Pattern</em>' container reference.
	 * @see #setContainingPattern(StoryPattern)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPattern_ContainingPattern()
	 * @see de.mdelab.mlstorypatterns.StoryPattern#getNegativeApplicationConditions
	 * @model opposite="negativeApplicationConditions" resolveProxies="false" transient="false" ordered="false"
	 * @generated
	 */
	StoryPattern getContainingPattern();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPattern#getContainingPattern <em>Containing Pattern</em>}' container reference.
	 * <!-- begin-user-doc
	 * --> <!-- end-user-doc -->
	 * @param value the new value of the '<em>Containing Pattern</em>' container reference.
	 * @see #getContainingPattern()
	 * @generated
	 */
	void setContainingPattern(StoryPattern value);

} // StoryPattern
